<?php

namespace App\Command;

use App\Service\Factorio;
use App\Service\RuleChecker;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

#[AsCommand(
    name: 'app:check',
    description: 'Check all online players',
)]
class CheckCommand extends Command
{
    public function __construct(
        private readonly Factorio    $factorio,
        private readonly RuleChecker $ruleChecker,
    )
    {
        parent::__construct();
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $io = new SymfonyStyle($input, $output);

        $players = $this->factorio->getOnlinePlayers();
        $rules = $this->ruleChecker->getRules();
        foreach ($players as $player) {
            $allowed = false;
            foreach ($rules as $rule) {
                $check = $rule->check($player);
//                $this->factorio->whisper($player, sprintf('Checking %s, %s', $rule->getName(), $check));
                if ($check->isWarning()) {
                    $this->factorio->whisper($player, sprintf('Checked %s. %s', $rule->getName(), $check));
                }
                if ($check->isAllowed()) {
                    $allowed = true;
                    break;
                }
            }
            if (!$allowed) {
                $this->factorio->kickPlayer($player, 'Time has expired on this server for today');
                $io->warning(sprintf('Kicked player %s', $player->getName()));
            }
        }

        return Command::SUCCESS;
    }
}
