<?php

namespace App\Command;

use App\Service\Factorio;
use App\Service\SimpleDatabase\PlayTimeRepository;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

#[AsCommand(
    name: 'app:users',
    description: 'List factorio server users',
)]
class UsersCommand extends Command
{
    public function __construct(
        private readonly Factorio           $factorio,
        private readonly PlayTimeRepository $playTimeRepository,
    )
    {
        parent::__construct();
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $io = new SymfonyStyle($input, $output);

        $players = $this->factorio->getOnlinePlayers();

        $io->table(['Name', 'Time'], array_map(fn($player) => [
            $player->getName(),
            $this->playTimeRepository->getPlayTimeOnDay($player),
        ], $players));

        return Command::SUCCESS;
    }
}
