<?php

namespace App\Service\Rules;

use App\Dto\Player;
use App\Service\SimpleDatabase\PlayTimeRepository;
use App\Service\SimpleDatabase\SimpleDataService;

class PlayTimeRule extends AbstractRule
{
    public function __construct(
        private readonly PlayTimeRepository $playTimeRepository,
        private readonly int                $defaultPlayTime = 60,
        private readonly int                $timeBetweenChecks = 1,
    ) {}

    private function timePerPlayer(Player $player)
    {
        $players = [
//            "Ardentsword" => "120",
        ];

        return $players[$player->getName()] ?? $this->defaultPlayTime;
    }

    public function check(Player $player): RuleResult
    {
        $today = new \DateTimeImmutable();
        $playTime = $this->playTimeRepository->getPlayTimeOnDay($player, $today);

        // If the player has no data or the data is from a different day, we reset the time
        if ($playTime === false) {
            $this->playTimeRepository->storePlayTime($player, $today, $this->timePerPlayer($player));
            return new RuleResult(RuleResultEnum::WARNING, sprintf('Extra time activated, set to %d minutes', $this->timePerPlayer($player)));
        }

        // If the player has time left, we decrease it and return denied if nothing left
        $playTime -= $this->timeBetweenChecks;
        $this->playTimeRepository->storePlayTime($player, $today, $playTime);

        if ($playTime <= 0) {
            return new RuleResult(RuleResultEnum::DENIED);
        } elseif ($playTime <= 5 || $playTime === 30) {
            return new RuleResult(RuleResultEnum::WARNING, sprintf('%d minute(s) left', $playTime));
        }

        return new RuleResult(RuleResultEnum::ALLOWED);
    }

    public function getName(): string
    {
        return sprintf('PlayTimeRule, limited play time');
    }
}