<?php

namespace App\Service\Rules;

use App\Dto\Player;

class TimeRule extends AbstractRule
{
    public function __construct(
        private readonly string $start = '19:00',
        private readonly string $end = '20:00',
    ) {}

    public function check(Player $player): RuleResult
    {
        $now = new \DateTimeImmutable();
        $start = new \DateTimeImmutable($this->start);
        $end = new \DateTimeImmutable($this->end);

        if ($now >= $start && $now <= $end) {
            // Always add 1 because we are a few seconds into the minute
            $timeLeft = $end->diff($now);
            $minutesLeft = $timeLeft->i + 1;
            $hoursLeft = $timeLeft->h;
            if ($hoursLeft == 0 && ($minutesLeft <= 5 || $minutesLeft === 30)) {
                return new RuleResult(RuleResultEnum::WARNING, sprintf('%d minute(s) left', $minutesLeft));
            }
            return new RuleResult(RuleResultEnum::ALLOWED);
        }

        return new RuleResult(RuleResultEnum::DENIED, 'After designed hours');
    }

    public function getName(): string
    {
        return sprintf('TimeRule, time is between %s and %s', $this->start, $this->end);
    }
}