<?php

namespace App\Service\SimpleDatabase;

use App\Dto\Player;

readonly class PlayTimeRepository
{
    public function __construct(
        private SimpleDataService $dataService,
    ) {}

    private function getKey(Player $player): string
    {
        return sprintf('playTime-%s', $player->getName());
    }

    public function storePlayTime(Player $player, \DateTimeImmutable $day, int $timeLeft): void
    {
        $this->dataService->set(
            $this->getKey($player),
            [
                'player' => $player->getName(),
                'timeLeft' => $timeLeft,
                'day' => $day->format('Y-m-d'),
            ]
        );
    }

    public function getPlayTimeRaw(Player $player): ?array
    {
        return $this->dataService->get($this->getKey($player));
    }

    public function getPlayTimeOnDay(Player $player, ?\DateTimeImmutable $day = null): false|int
    {
        if ($day === null) {
            $day = new \DateTimeImmutable();
        }

        $data = $this->getPlayTimeRaw($player);
        if (!$data || $data['day'] !== $day->format('Y-m-d')) {
            return false;
        }
        return $data['timeLeft'];
    }
}