<?php

namespace App\Service\SimpleDatabase;

use Symfony\Component\DependencyInjection\Attribute\Autowire;

class SimpleDataService
{
    private ?array $dataCache = null;

    public function __construct(
        #[Autowire('%kernel.project_dir%/data.json')]
        private readonly string $dataFile
    ) {}

    public function set(string $key, array $data): self
    {
        if ($this->dataCache === null) {
            $this->dataCache = $this->getAll();
        }
        $this->dataCache[$key] = $data;

        $this->writeCache();

        return $this;
    }

    public function get(string $key): ?array
    {
        return $this->getAll()[$key] ?? null;
    }

    public function getAll(): array
    {
        if ($this->dataCache !== null) {
            return $this->dataCache;
        }

        if (!file_exists($this->dataFile)) {
            $this->dataCache = [];
        } else {
            $this->dataCache = json_decode(file_get_contents($this->dataFile), true);
        }

        return $this->dataCache;
    }

    private function writeCache(): void
    {
        file_put_contents($this->dataFile, json_encode($this->dataCache, JSON_PRETTY_PRINT));
    }
}